@@ -1,4 +1,5 @@
-Heading <- function(name = NULL, override = TRUE, character.only = FALSE) 
+Heading <- function(name = NULL, override = TRUE, character.only = FALSE,
+		    nearData = TRUE) 
     stop("This is a pseudo-function, not meant to be called.")
     
 Justify <- function(labels, data=labels)
